Structs
Enums
- Error
- The error type for kdeets.
Functions
- list_
versions - Returns all published version strings for a crate from the crates.io index.
- version_
exists - Returns
trueif the given version of a crate exists in the crates.io index, orfalseif the crate is found but the version is absent.