Crate kdeets_lib

Crate kdeets_lib 

Structs

CrateVersions
RustVersions
Setup

Enums

Error
The error type for kdeets.

Functions

list_versions
Returns all published version strings for a crate from the crates.io index.
version_exists
Returns true if the given version of a crate exists in the crates.io index, or false if the crate is found but the version is absent.